@@ -146,6 +146,14 @@ class VehicleClient:
         # TODO: below str() conversion is only needed for legacy reason and should be removed in future
         self.client.call('simToggleControl', str(camera_name), toggle, vehicle_name)
 
+    def simSetWind(self, wind):
+        """
+        Set simulated wind, in World frame, NED direction, m/s
+        Args:
+            wind (Vector3r): Wind, in World frame, NED direction, in m/s 
+        """
+        self.client.call('simSetWind', wind)
+
     def simGetGroundTruthKinematics(self, vehicle_name = ''):
         kinematics_state = self.client.call('simGetGroundTruthKinematics', vehicle_name)
         return KinematicsState.from_msgpack(kinematics_state)
